@@ -23,7 +23,7 @@ from enum import Enum
 if typing.TYPE_CHECKING:
     from typing import Dict, List, Optional, Union
     from datetime import datetime
-    from ask_sdk_model.interfaces.amazonpay.model.v1.billing_agreement_details import BillingAgreementDetails
+    from ask_sdk_model.interfaces.amazonpay.model.v1.billing_agreement_details import BillingAgreementDetailsV1
 
 
 class SetupAmazonPayResult(object):
@@ -45,7 +45,7 @@ class SetupAmazonPayResult(object):
     supports_multiple_types = False
 
     def __init__(self, billing_agreement_details=None):
-        # type: (Optional[BillingAgreementDetails]) -> None
+        # type: (Optional[BillingAgreementDetailsV1]) -> None
         """Setup Amazon Pay Result Object. It is sent as part of the reponse to SetupAmazonPay request.
 
         :param billing_agreement_details: 
